==> geant4.10.01.p01.tar.gz: geant4.10.01.p01/source/processes/hadronic/models/de_excitation/util/src/G4ConstantLevelDensityParameter.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
// Hadronic Process: Nuclear De-excitations
//    Constant level density parameter (for photon evaporation)
//
// by C. Dallapiccola (Nov 1998)
//


#include "G4ConstantLevelDensityParameter.hh"
#include "G4SystemOfUnits.hh"
#include "G4HadronicException.hh"

G4ConstantLevelDensityParameter::G4ConstantLevelDensityParameter() 
  :  EvapLevelDensityParameter(0.125/MeV) 
{}

G4ConstantLevelDensityParameter::~G4ConstantLevelDensityParameter()
{}

==> geant4.10.04.tar.gz: geant4.10.04/source/processes/hadronic/models/de_excitation/util/src/G4ConstantLevelDensityParameter.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
// Hadronic Process: Nuclear De-excitations
//    Constant level density parameter (for photon evaporation)
//
// by C. Dallapiccola (Nov 1998)
//

#include "G4ConstantLevelDensityParameter.hh"
#include "G4SystemOfUnits.hh"

G4ConstantLevelDensityParameter::G4ConstantLevelDensityParameter() 
  :  EvapLevelDensityParameter(0.125/CLHEP::MeV) 
{}

G4ConstantLevelDensityParameter::~G4ConstantLevelDensityParameter()
{}
